/* --COPYRIGHT--,BSD
 * Copyright (c) 2016, Texas Instruments Incorporated
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * *  Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * *  Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * *  Neither the name of Texas Instruments Incorporated nor the names of
 *    its contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
 * EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * --/COPYRIGHT--*/

/*******************************************************************************
 *
 *  drv81xxx-Q1-RegMap.h - Declaration file for utility functions and global variables
 *  DRV81xxx-Q1EVM_FIRMWARE
 *  01/05/2024
 *
 ******************************************************************************/
#ifndef DRV81xxxQ1_REGMAP_H_
#define DRV81xxxQ1_REGMAP_H_

#include "dataTypeDefinition.h"

// MACROs

// DRV8xxxQ1 SPI Register Addresses
#define Standard_Diagnosis_Register         (uint8_t)(0x3F)         // Standard Diagnosis Register
#define Output_Control_Register             (uint8_t)(0x00)         // Output Control Register
#define Bulb_Inrush_Register                (uint8_t)(0x01)         // Bulb Inrush Register
#define IN0_Map_Register                    (uint8_t)(0x04)         // IN0 Map Register
#define IN1_Map_Register                    (uint8_t)(0x05)         // IN1 Map Register
#define Input_Status_Monitor_Register       (uint8_t)(0x06)         // Input Status Monitor Register
#define Open_Load_Current_Control_Register  (uint8_t)(0x08)         // Open Load Current Control Register
#define Output_Status_Monitor_Register      (uint8_t)(0x09)         // Output Status Monitor Register
#define Open_Load_at_ON_Register            (uint8_t)(0x0A)         // Open Load at ON Register
#define EN_OLON_Register                    (uint8_t)(0x0B)         // EN OLON Register
#define Configuration_Register              (uint8_t)(0x0C)         // Configuration Register
#define Output_Clear_Latch_Register         (uint8_t)(0x0D)         // Output Clear Latch Register
#define FPWM_Register                       (uint8_t)(0x0E)         // FPWM Register
#define PWM0_Configuration_Register         (uint8_t)(0x10)         // PWM0 Configuration Register
#define PWM1_Configuration_Register         (uint8_t)(0x14)         // PWM1 Configuration Register
#define PWM_OUT_Register                    (uint8_t)(0x24)         // PWM_OUT Register
#define MAP_PWM_Register                    (uint8_t)(0x25)         // MAP_PWM Register
#define Configuration2_Register             (uint8_t)(0x28)         // Configuration2 Register

// Structure variables for the DRV8xx2 registers
typedef struct DRV8xxxQ1_REG
{
    uint16_t standard_diag_reg;
    uint16_t output_control_reg;
    uint16_t bulb_inrush_reg;
    uint16_t IN0_map_reg;
    uint16_t IN1_map_reg;
    uint16_t input_status_monitor_reg;
    uint16_t OL_current_control_reg;
    uint16_t output_status_monitor_reg;
    uint16_t OL_at_ON_reg;
    uint16_t EN_OLON_reg;
    uint16_t config_reg;
    uint16_t output_clear_latch_reg;
    uint16_t FPWM_reg;
    uint16_t PWM0_config_reg;
    uint16_t PWM1_config_reg;
    uint16_t PWM_out_reg;
    uint16_t MAP_PWM_reg;
    uint16_t Config_reg2;
} DRV8xxxQ1_REG_t;                            // Starting address 0x6300 total 36 bytes

#endif // DRV81xxxQ1_REGMAP_H_
