/* --COPYRIGHT--,BSD
 * Copyright (c) 2016, Texas Instruments Incorporated
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * *  Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * *  Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * *  Neither the name of Texas Instruments Incorporated nor the names of
 *    its contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
 * EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * --/COPYRIGHT--*/

/*******************************************************************************
 *
 *  drv81xxxQ1.h - Declaration file for utility functions and global variables
 *  DRV81xxx-Q1EVM_FIRMWARE
 *  01/05/2024
 *  Murugavel Raju
 *
 ******************************************************************************/
#ifndef DRV81xxxQ1_H_
#define DRV81xxxQ1_H_
/******************************************************************************
 * HEADER FILES
 *****************************************************************************/
#include "../../drv81xxx-Q1/include/drv81xxx-Q1-RegMap.h"
#include "msp430.h"

/******************************************************************************
 * Defined Quantities
 *****************************************************************************/
#define SYS_TICK                 5          // System periodic
#define LED_TIMEOUT            125          // Count to blink LED with 1s period
#define REG_READ_PERIOD         11          // Register read period 12 x 8 ms = 96 ms
#define ADC12scale              68

/******************************************************************************
 * MACROS
 *****************************************************************************/
// GPIO Port 1 Definitions
#define IDR_3              BIT0    // P1.0: EVM ID3 setting
#define IDR_4              BIT1    // P1.1: EVM ID4 setting
#define PUSH               BIT2    // P1.2: EVM Push button input
#define MCU_STATUS         BIT6    // P1.6: Status LED output

// GPIO Port 2 Definitions
#define TP1                BIT2    // P2.2: Test point 1
#define TP2                BIT3    // P2.3: Test point 2
#define TP3                BIT4    // P2.4: Test point 3
#define FAULT_STATUS       BIT5    // P2.4: Fault Status LED output

// GPIO Port 3 Definitions
#define TP6                BIT0    // P3.0: Test point 6
#define GUI_STATUS         BIT5    // P3.5: GUI Status LED output
#define DRV_STATUS         BIT6    // P3.6: DRV Status LED output

// GPIO Port 4 Definitions
#define CH8                BIT2    // P4.2: Channel 8 LED output
#define CH7                BIT3    // P4.3: Channel 7 LED output
#define CH6                BIT4    // P4.4: Channel 6 LED output
#define CH5                BIT5    // P4.5: Channel 5 LED output
#define CH1                BIT6    // P4.6: Channel 1 LED output
#define CH2                BIT7    // P4.7: Channel 2 LED output

// GPIO Port 5 Definitions
#define IDR_0              BIT3    // P5.3: EVM ID0 setting
#define IDR_1              BIT4    // P5.4: EVM ID1 setting
#define IDR_2              BIT5    // P5.5: EVM ID2 setting
#define TP4                BIT6    // P4.6: Test Point TP4
#define TP5                BIT7    // P4.7: Test Point TP6

// GPIO Port 6 Definitions
#define VBAT_MON           BIT0    // VBAT_MON analog input channel A0

// GPIO Port 7 Definitions
// Unused port

// GPIO Port 8 Definitions
#define CH3                BIT0    // P8.0: Channel 3 LED output
#define CH4                BIT1    // P8.1: Channel 4 LED output
#define UART_TXD           BIT2    // P8.2: UART TXD
#define UART_RXD           BIT3    // P8.3: UART RXD
#define SCLK               BIT4    // P8.4: DRV SCLK input
#define SDI                BIT5    // P8.5: DRV SDI input
#define SDO                BIT6    // P8.6: DRV SDO output
#define nSCS               BIT7    // P8.7: DRV sSCS input

// GPIO Port 9 Definitions
#define IN_0               BIT1    // P9.1: DRV IN0 input
#define IN_1               BIT2    // P9.2: DRV IN1 input
#define nSLEEP             BIT3    // P9.3: DRV nSLEEP input

// nSLEEP GPIO macro
#define set_nSLEEP_hi             P9OUT |= nSLEEP
#define set_nSLEEP_lo             P9OUT &= ~nSLEEP
#define read_nSLEEP_pin           P9IN & nSLEEP

// IN0 GPIO macro
#define set_IN0_hi                P9OUT |= IN_0
#define set_IN0_lo                P9OUT &= ~IN_0
#define read_IN0_pin              P9IN & IN_0

// IN1 GPIO macro
#define set_IN1_hi                P9OUT |= IN_1
#define set_IN1_lo                P9OUT &= ~IN_1
#define read_IN1_pin              P9IN & IN_1

#define toggle_status_led         P1OUT ^= MCU_STATUS

#define read_ID4_pin              P1IN & IDR_4
#define read_ID2_1_0_pins         P5IN & (IDR_2 | IDR_1 | IDR_0)

#define REV_PG1_0          0
#define REV_PG2_0          1

/******************************************************************************
* DATA STRUCTURES
 *****************************************************************************/
typedef struct DRV8xxxQ1_Obj_t
{
  float Firmware_Version;          // Firmware version

  // Device Parameters
  volatile uint16_t deviceID;      // 0:DRV81008-Q1, 1:DRV81004,2:DRV81080,3:DRV81242,4:DRV81602,5:DRV81620
  volatile uint8_t IN0;            // 0: IN0 disabled , 1: IN0 enabled
  volatile uint8_t IN1;            // 0: IN1 disabled , 1: IN1 enabled
  volatile uint8_t nSleep;         // 0: nSLEEP disabled , 1: nSLEEP enabled

  // Register Read Write
  volatile uint16_t   ManWriteAddr;
  volatile uint16_t   ManReadAddr;
  volatile uint16_t   ManWriteData;
  volatile uint16_t   ManReadData;
  volatile bool       ManWriteCmd;
  volatile bool       ManReadCmd;
  volatile bool       ReadCmd;

  volatile uint16_t   revID;

  // VM supply voltage
  volatile uint16_t   VMvoltage;

  volatile uint8_t    AutoRead;    // 0: Auto Read off, 1: Auto Read on
} DRV8xxxQ1_Obj_t;                 // Starting address 0x6200 total 27 bytes includes a filler byte after ManReadCmd for word alignment in MSP430

// Utility variables
volatile uint8_t RegReadPeriod;
volatile uint8_t ReadCmd;
volatile uint16_t Device_ID;
unsigned int SYS_TICK_CNT;         // count to determine periodic system wake-up
unsigned int LED_TOGGLE_CNT;       // count to determine if LED should be toggled
volatile int ADC12offset;
volatile unsigned char ADC12offsetpositive;
volatile unsigned char ADC12offsetnegative;

/******************************************************************************
 * EXTERN DECLARATIONS
 *****************************************************************************/
extern volatile DRV8xxxQ1_REG_t gDeviceSpiReg;
extern volatile DRV8xxxQ1_Obj_t gBrushedObj;

/******************************************************************************
 * API Prototypes
 *****************************************************************************/
void mcu_init(void);
void getEVMID(void);
void drv81xxxQ1_init();
void drv81xxxQ1_RegistersRead();
void UpdateGUI_Register(void);
void UpdateDeviceControls_drv81xxxQ1(void);

/*****************************************************************************/
#endif // DRV8xx2_H_
