/* --COPYRIGHT--,BSD
 * Copyright (c) 2016, Texas Instruments Incorporated
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * *  Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * *  Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * *  Neither the name of Texas Instruments Incorporated nor the names of
 *    its contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
 * EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * --/COPYRIGHT--*/

/*******************************************************************************
 *  main.c - c file for main function
 *  DRV81xxx-Q1EVM_FIRMWARE
 *  01/05/2024
 *  Murugavel Raju
 ******************************************************************************/
#include <msp430.h>
#include "drv81xxx-Q1/include/drv81xxx-Q1.h"
#include "SPI.h"
#include "Serial_Cmd_Monitor.h"

extern unsigned int rxData;
extern unsigned int rxTrue;

// Main
int main(void)
{
    mcu_init();                                      // Initialize MCU peripherals
    drv81xxxQ1_init();                               // Firmware version and GUI variables initialization
    getEVMID();                                      // Read EVM ID, REV ID and set value for deviceID and revID global variables

    // Serial protocol between GUI USB and MCU UART initialization
    ClearBufferRelatedParam();                       // GUI Composer Monitor Initialization
    __bis_SR_register(GIE);                          // Global interrupts enable

    while (1)
    {
        // WDTCTL = WDT_ARST_250;                       // Watchdog mode 250 ms with ACLK

        // DRV control
        UpdateDeviceControls_drv81xxxQ1();           // read the GUI values and pass to device
        UpdateGUI_Register();                        // registers read and write routines
        drv81xxxQ1_RegistersRead();                  // Set trigger for reading drv81xxxQ1 Registers
        P4OUT = gDeviceSpiReg.output_control_reg & 0xFF;
        // End DRV control

        // REMOVE BELOW CODE FOR NEW LAYOUT EVM
        switch (gDeviceSpiReg.output_control_reg & 0x03)
        {
        case 0:
            P8OUT = 0;
            break;
        case 1:
            P8OUT = 2;
            break;
        case 2:
            P8OUT = 1;
            break;
        case 3:
            P8OUT = 3;
            break;
        default:
            break;
        }

        __bis_SR_register(LPM0_bits + GIE);          // Enter LPM0
    }
}

// Timer2_A0 Interrupt Service Routine, periodic wake up and Status LED timing derived from timer
#pragma vector=TIMER2_A0_VECTOR
__interrupt void TimerA2CCR0(void)
{
    LED_TOGGLE_CNT++;
    SYS_TICK_CNT++;
    if (SYS_TICK_CNT > SYS_TICK)
    {
        SYS_TICK_CNT = 0;
        __bic_SR_register_on_exit(LPM0_bits);        // Clear LPM0 bits
    }
}// End Timer2_A0 Interrupt Service Routine, periodic wake up and Status LED timing derived from timer
